# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.96) ? 1 : 0);' 2>/dev/null || echo 0)
%global older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)
%global even_older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

# noarch, but to avoid debug* files interfering with manifest test:
%global debug_package %{nil}

Name:		perl-Test-Version
Version:	2.05
Release:	1.%{__distinit}%{__distvers}
Summary:	Check to see that versions in modules are sane
License:	Artistic 2.0
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Test-Version/
Source0:	http://search.cpan.org/CPAN/authors/id/P/PL/PLICEASE/Test-Version-%{version}.tar.gz
Patch10:	Test-Version-2.04-Test::More-subtests.patch
Patch11:	Test-Version-2.05-Test::More-done_testing.patch
Patch12:	Test-Version-2.03-Test::More-note.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# ===================================================================
# Module build requirements
# ===================================================================
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# ===================================================================
# Module requirements
# ===================================================================
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Find::Rule::Perl)
BuildRequires:	perl(Module::Metadata) >= 1.000020
BuildRequires:	perl(parent)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(version) >= 0.86
BuildRequires:	perl(warnings)
# ===================================================================
# Regular test suite requirements
# ===================================================================
BuildRequires:	perl(blib) >= 1.01
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Test::Exception)
BuildRequires:	perl(Test::Tester)
# ===================================================================
# Author/Release test requirements
#
# Don't run these tests or include their requirements if we're
# bootstrapping, as many of these modules require each other for
# their author/release tests.
# ===================================================================
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(English)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::CPAN::Changes) >= 0.19
BuildRequires:	perl(Test::CPAN::Meta::JSON)
BuildRequires:	perl(Test::DistManifest)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
%endif
# ===================================================================
# Runtime requirements
# ===================================================================
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
This module's goal is to be a one stop shop for checking to see that your
versions across your dist are sane.

%prep
%setup -q -n Test-Version-%{version}

# We have to patch the test suite if we have an old Test::More
#
# subtests without done_testing require Test::More ≥ 0.96
%if %{old_test_more}
%patch10
%endif
# done_testing requires Test::More ≥ 0.88
%if %{older_test_more}
%patch11
%endif
# note() requires Test::More ≥ 0.82
%if %{even_older_test_more}
%patch12
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes CONTRIBUTING README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Version.3*

%changelog
* Sun Sep 18 2016 Paul Howarth <paul@city-fan.org> - 2.05-1
- Update to 2.05
  - Bump requirement for newer version of Module::Metadata (again); required
    for ignore_unindexable
- Update patches as needed

* Thu Jun 23 2016 Paul Howarth <paul@city-fan.org> - 2.04-1
- Update to 2.04
  - Bump requirement for a newer version of Module::Metadata
    (the version that comes with Perl 5.14 cannot handle package block syntax)
- BR: perl-generators where available
- Simplify find command using -delete
- Update patches as needed

* Mon Jun 29 2015 Paul Howarth <paul@city-fan.org> - 2.03-1
- Update to 2.03
  - Added 'multiple' option to check each version inside a .pm file with
    multiple packages
  - Remove annoying warnings when version_ok called by itself (GH#5)
- Update patches as needed

* Tue Jun 23 2015 Paul Howarth <paul@city-fan.org> - 2.01-4
- Disable use of Test::Vars with Perl 5.22
  (https://github.com/gfx/p5-Test-Vars/issues/11)

* Tue May 19 2015 Paul Howarth <paul@city-fan.org> - 2.01-1
- Update to 2.01
  - Fix failing test in t/all-generated.t
- Update patches as needed

* Thu May  7 2015 Paul Howarth <paul@city-fan.org> - 2.00-1
- Update to 2.00
  - Added filename_match setting
- Update patches as needed

* Wed May  6 2015 Paul Howarth <paul@city-fan.org> - 1.050000-1
- Update to 1.05
  - New maintainer (PLICEASE) updated meta
- Retained six-digit version number for rpm to maintain upgrade path, until
  upstream reaches version 2 anyway
- Update patches as needed

* Tue Oct 21 2014 Paul Howarth <paul@city-fan.org> - 1.004001-1
- Update to 1.004001
  - Improved consistent check diagnostics (GH#11)
- Update patches as needed

* Mon Oct 20 2014 Paul Howarth <paul@city-fan.org> - 1.004000-1
- Update to 1.004000
  - Add consistent check (GH#10)
- Update patches as needed

* Wed Sep 24 2014 Paul Howarth <paul@city-fan.org> - 1.003001-1
- Update to 1.003001
  - Skip packages unindexable by pause (GH#4)
  - Remove inline and remove _get_version; trying to skip test there won't work
    (GH#4)
- Update patches as needed

* Mon Sep 15 2014 Paul Howarth <paul@city-fan.org> - 1.002004-5
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- BR: perl(Test::CPAN::Changes) and perl(Test::Synopsis) unconditionally

* Thu Nov 21 2013 Paul Howarth <paul@city-fan.org> - 1.002004-1
- Update to 1.002004
  - Fix bugs in argument handling
  - Fix whitespace
- Update patches as needed

* Tue Oct 15 2013 Paul Howarth <paul@city-fan.org> - 1.002003-1
- Update to 1.002003
  - Fix synopsis (https://github.com/xenoterracide/Test-Version/pull/6)
  - Change Dist::Zilla plugins
  - Remove old documentation that no longer applies
  - Fix misgithap
  - More dist.ini updates
- Update patches and buildreqs as needed
- Choose appropriate system speller as we no longer use Pod::Wordlist::hanekomu
  (which forces the speller to be aspell)

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 1.002001-11
- Perl 5.18 rebuild

* Fri Jun 14 2013 Paul Howarth <paul@city-fan.org> - 1.002001-10
- Fix FTBFS with current test modules
  - Disable Test::Kwalitee's "use_strict" test
  - Schwern not in dictionary
- Update patch for building with ExtUtils::MakeMaker < 6.30
- Renumber and re-order patches

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.002001-7
- Perl 5.16 post-bootstrap rebuild

* Mon Jul  9 2012 Paul Howarth <paul@city-fan.org> - 1.002001-6
- BR: perl(Test::Tester)
- Drop buildreqs perl(File::Find), perl(strict) and perl(warnings) as they're
  not dual-lived

* Wed Mar 14 2012 Paul Howarth <paul@city-fan.org> - 1.002001-1
- Update to 1.002001:
  - Fix metadata caused by a bug in DZP::GitHub after asking repo to be
    unlinked from gitpan
- Don't need to remove empty directories from buildroot
- Use %%{_fixperms} macro rather than our own chmod incantation
- Drop support for distributions prior to FC-3:
  - BR: perl(Test::Perl::Critic) unconditionally
  - BR: aspell-en unconditionally
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
- Update patch for building without Test::Requires if necessary

* Tue Jan 10 2012 Paul Howarth <paul@city-fan.org> - 1.002000-1
- Update to 1.002000:
  - Use Module::Metadata
  - Allow disabling of 'has_version'
  - Require at least 1 version
  - Allow for checking that a module is_strict
- BR: perl(Test::Requires)
- Update patches for building with old ExtUtils::MakeMaker and Test::More
  versions
- Add patch for building without Test::Requires if necessary

* Fri Dec  2 2011 Paul Howarth <paul@city-fan.org> - 1.001003-1
- Update to 1.001003-TRIAL version:
  - Check if versions are strict
  - Provide is_strict setting to decide what to do if they aren't strict
  - Provide has_version setting to disable that a module must always have a
    version
  - Use perl decimal style semantic versioning because of bugs in EUMM with
    vstring versions
  - Fix some issues in the pod
  - Use Module::Metadata - apparently it's closer to how Perl works than
    Module::Extract::VERSION
- perl(Carp) is now a module requirement rather than just a test suite
  requirement
- Add BR: perl(Test::Exception) for test suite
- BR: perl(Module::Metadata) rather than perl(Module::Extract::VERSION)
- BR: perl(strict) and perl(warnings) for completeness
- Update patches for building with old ExtUtils::MakeMaker and Test::More
  versions

* Thu Aug 11 2011 Paul Howarth <paul@city-fan.org> - 1.0.0-2
- Don't run the author/release tests when bootstrapping
- BR: perl(Test::DistManifest) unconditionally
- Additional BR's for improved release test coverage:
  - aspell-en/aspell-en-gb
  - perl(Pod::Wordlist::hanekomu)
  - perl(Test::CPAN::Meta::JSON)
  - perl(Test::Mojibake)
  - perl(Test::Vars)

* Wed Aug  3 2011 Paul Howarth <paul@city-fan.org> - 1.0.0-1
- Initial RPM version
